summaryrefslogtreecommitdiffstats
path: root/src/H5Farray.c
diff options
context:
space:
mode:
Diffstat (limited to 'src/H5Farray.c')
-rw-r--r--src/H5Farray.c27
1 files changed, 14 insertions, 13 deletions
diff --git a/src/H5Farray.c b/src/H5Farray.c
index 25ce208..27ec922 100644
--- a/src/H5Farray.c
+++ b/src/H5Farray.c
@@ -114,7 +114,7 @@ H5F_arr_create (H5F_t *f, struct H5O_layout_t *layout/*in,out*/)
*/
herr_t
H5F_arr_read (H5F_t *f, const struct H5O_layout_t *layout,
- const struct H5O_compress_t *comp, const struct H5O_efl_t *efl,
+ const struct H5O_pline_t *pline, const struct H5O_efl_t *efl,
const hsize_t _hslab_size[], const hsize_t mem_size[],
const hssize_t mem_offset[], const hssize_t file_offset[],
const H5D_transfer_t xfer_mode, void *_buf/*out*/)
@@ -182,11 +182,11 @@ H5F_arr_read (H5F_t *f, const struct H5O_layout_t *layout,
}
/*
* Compression cannot be used for contiguous data.
*/
- if (comp && H5Z_NONE!=comp->method) {
+ if (pline && pline->nfilters>0) {
HRETURN_ERROR (H5E_IO, H5E_READERROR, FAIL,
- "compression is not allowed for contiguous data");
+ "filters are not allowed for contiguous data");
}
/*
@@ -286,7 +286,7 @@ H5F_arr_read (H5F_t *f, const struct H5O_layout_t *layout,
"unable to copy into a proper hyperslab");
}
}
- if (H5F_istore_read (f, layout, comp, file_offset, hslab_size,
+ if (H5F_istore_read (f, layout, pline, file_offset, hslab_size,
buf)<0) {
HRETURN_ERROR (H5E_IO, H5E_READERROR, FAIL, "chunked read failed");
}
@@ -332,10 +332,11 @@ H5F_arr_read (H5F_t *f, const struct H5O_layout_t *layout,
*/
herr_t
H5F_arr_write (H5F_t *f, const struct H5O_layout_t *layout,
- const struct H5O_compress_t *comp, const struct H5O_efl_t *efl,
- const hsize_t _hslab_size[], const hsize_t mem_size[],
- const hssize_t mem_offset[], const hssize_t file_offset[],
- const H5D_transfer_t xfer_mode, const void *_buf)
+ const struct H5O_pline_t *pline,
+ const struct H5O_efl_t *efl, const hsize_t _hslab_size[],
+ const hsize_t mem_size[], const hssize_t mem_offset[],
+ const hssize_t file_offset[], const H5D_transfer_t xfer_mode,
+ const void *_buf)
{
const uint8 *buf = (const uint8 *)_buf; /*cast for arithmetic */
hssize_t file_stride[H5O_LAYOUT_NDIMS]; /*strides through file */
@@ -399,11 +400,11 @@ H5F_arr_write (H5F_t *f, const struct H5O_layout_t *layout,
}
/*
* Compression cannot be used for contiguous data
*/
- if (comp && H5Z_NONE!=comp->method) {
+ if (pline && pline->nfilters>0) {
HRETURN_ERROR (H5E_IO, H5E_WRITEERROR, FAIL,
- "compression is not allowed for contiguous data");
+ "filters are not allowed for contiguous data");
}
/*
@@ -503,7 +504,7 @@ printf("nelmts=%lu, min=%lu, max=%lu\n", temp, min, max);
"unable to copy from a proper hyperslab");
}
}
- if (H5F_istore_write (f, layout, comp, file_offset, hslab_size,
+ if (H5F_istore_write (f, layout, pline, file_offset, hslab_size,
buf)<0) {
HRETURN_ERROR (H5E_IO, H5E_WRITEERROR, FAIL,
"chunked write failed");
@@ -182,11 +182,11 @@ H5F_arr_read (H5F_t *f, const struct H5O_layout_t *layout,
}
/*
- * Compression cannot be used for contiguous data.
+ * Filters cannot be used for contiguous data.
*/
@@ -399,11 +400,11 @@ H5F_arr_write (H5F_t *f, const struct H5O_layout_t *layout,
}
/*
- * Compression cannot be used for contiguous data
+ * Filters cannot be used for contiguous data
*/